@@ -35,7 +35,7 @@ private:
     
     QLineEdit* m_playerName;
     QPixmap* m_playerPreviewPixmap;
-    QPixmap* m_playerPreviewPixmapAlphaChannel;
+    QImage* m_playerPreviewImageAlphaChannel;
     
     QLabel* m_playerPreviewPixmapLabel;
     QLabel* m_playerAuthor;
@@ -57,13 +57,13 @@ private:
     PlayerSettings* m_playerSettings;
     
 public:
-    PlayerSelectorItem(const QString& playerId, PlayerSettings* playerSettings, QWidget* parent = 0);
+    PlayerSelectorItem(const QString& playerId, PlayerSettings* playerSettings, QWidget* parent = nullptr);
     ~PlayerSelectorItem();
     
     void setPlayerPreviewPixmap(const QPixmap& pixmap);
     void setPlayerAuthor(const QString& name, const QString& mail);
 
-private slots:
+private Q_SLOTS:
     void selectionChanged(bool selectionState);
     void settingsChanged();
 
